# (Slowed + Reverb)
Create slowed and reverb songs with python.

Fork of a now unsupported project

**Installation**
```
pip install slowrevpy
```
**Dependencies**

Pedalboard (https://github.com/spotify/pedalboard)
